#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ProductSimpleInfo import ProductSimpleInfo
from alipay.aop.api.domain.VenueOrderTradeInfo import VenueOrderTradeInfo


class AlipayCommerceSportsVenueOrderSyncModel(object):

    def __init__(self):
        self._create_time = None
        self._order_status = None
        self._order_type = None
        self._out_order_id = None
        self._out_sub_venue_id = None
        self._out_venue_id = None
        self._product_group_list = None
        self._sub_venue_id = None
        self._total_amount = None
        self._trade_info_list = None
        self._user_id = None
        self._venue_id = None

    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def out_sub_venue_id(self):
        return self._out_sub_venue_id

    @out_sub_venue_id.setter
    def out_sub_venue_id(self, value):
        self._out_sub_venue_id = value
    @property
    def out_venue_id(self):
        return self._out_venue_id

    @out_venue_id.setter
    def out_venue_id(self, value):
        self._out_venue_id = value
    @property
    def product_group_list(self):
        return self._product_group_list

    @product_group_list.setter
    def product_group_list(self, value):
        if isinstance(value, list):
            self._product_group_list = list()
            for i in value:
                if isinstance(i, ProductSimpleInfo):
                    self._product_group_list.append(i)
                else:
                    self._product_group_list.append(ProductSimpleInfo.from_alipay_dict(i))
    @property
    def sub_venue_id(self):
        return self._sub_venue_id

    @sub_venue_id.setter
    def sub_venue_id(self, value):
        self._sub_venue_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_info_list(self):
        return self._trade_info_list

    @trade_info_list.setter
    def trade_info_list(self, value):
        if isinstance(value, list):
            self._trade_info_list = list()
            for i in value:
                if isinstance(i, VenueOrderTradeInfo):
                    self._trade_info_list.append(i)
                else:
                    self._trade_info_list.append(VenueOrderTradeInfo.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def venue_id(self):
        return self._venue_id

    @venue_id.setter
    def venue_id(self, value):
        self._venue_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.out_sub_venue_id:
            if hasattr(self.out_sub_venue_id, 'to_alipay_dict'):
                params['out_sub_venue_id'] = self.out_sub_venue_id.to_alipay_dict()
            else:
                params['out_sub_venue_id'] = self.out_sub_venue_id
        if self.out_venue_id:
            if hasattr(self.out_venue_id, 'to_alipay_dict'):
                params['out_venue_id'] = self.out_venue_id.to_alipay_dict()
            else:
                params['out_venue_id'] = self.out_venue_id
        if self.product_group_list:
            if isinstance(self.product_group_list, list):
                for i in range(0, len(self.product_group_list)):
                    element = self.product_group_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_group_list[i] = element.to_alipay_dict()
            if hasattr(self.product_group_list, 'to_alipay_dict'):
                params['product_group_list'] = self.product_group_list.to_alipay_dict()
            else:
                params['product_group_list'] = self.product_group_list
        if self.sub_venue_id:
            if hasattr(self.sub_venue_id, 'to_alipay_dict'):
                params['sub_venue_id'] = self.sub_venue_id.to_alipay_dict()
            else:
                params['sub_venue_id'] = self.sub_venue_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.trade_info_list:
            if isinstance(self.trade_info_list, list):
                for i in range(0, len(self.trade_info_list)):
                    element = self.trade_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.trade_info_list[i] = element.to_alipay_dict()
            if hasattr(self.trade_info_list, 'to_alipay_dict'):
                params['trade_info_list'] = self.trade_info_list.to_alipay_dict()
            else:
                params['trade_info_list'] = self.trade_info_list
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.venue_id:
            if hasattr(self.venue_id, 'to_alipay_dict'):
                params['venue_id'] = self.venue_id.to_alipay_dict()
            else:
                params['venue_id'] = self.venue_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceSportsVenueOrderSyncModel()
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'out_sub_venue_id' in d:
            o.out_sub_venue_id = d['out_sub_venue_id']
        if 'out_venue_id' in d:
            o.out_venue_id = d['out_venue_id']
        if 'product_group_list' in d:
            o.product_group_list = d['product_group_list']
        if 'sub_venue_id' in d:
            o.sub_venue_id = d['sub_venue_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'trade_info_list' in d:
            o.trade_info_list = d['trade_info_list']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'venue_id' in d:
            o.venue_id = d['venue_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechOceanbaseVerificationcodeVerifyModel(object):

    def __init__(self):
        self._code = None
        self._invalid = None
        self._passport_id = None
        self._scene = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def invalid(self):
        return self._invalid

    @invalid.setter
    def invalid(self, value):
        self._invalid = value
    @property
    def passport_id(self):
        return self._passport_id

    @passport_id.setter
    def passport_id(self, value):
        self._passport_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.invalid:
            if hasattr(self.invalid, 'to_alipay_dict'):
                params['invalid'] = self.invalid.to_alipay_dict()
            else:
                params['invalid'] = self.invalid
        if self.passport_id:
            if hasattr(self.passport_id, 'to_alipay_dict'):
                params['passport_id'] = self.passport_id.to_alipay_dict()
            else:
                params['passport_id'] = self.passport_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechOceanbaseVerificationcodeVerifyModel()
        if 'code' in d:
            o.code = d['code']
        if 'invalid' in d:
            o.invalid = d['invalid']
        if 'passport_id' in d:
            o.passport_id = d['passport_id']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskInstanceInfo(object):

    def __init__(self):
        self._current_indicator = None
        self._incentive_mode = None
        self._incentive_rule = None
        self._max_incentive_count = None
        self._published_point_amount = None
        self._status = None
        self._target_indicator = None
        self._task_end_time = None
        self._task_instance_id = None
        self._task_logo = None
        self._task_name = None
        self._task_start_time = None
        self._task_template_id = None
        self._task_type = None
        self._total_point_amount = None
        self._unexchange_point_amount = None

    @property
    def current_indicator(self):
        return self._current_indicator

    @current_indicator.setter
    def current_indicator(self, value):
        self._current_indicator = value
    @property
    def incentive_mode(self):
        return self._incentive_mode

    @incentive_mode.setter
    def incentive_mode(self, value):
        self._incentive_mode = value
    @property
    def incentive_rule(self):
        return self._incentive_rule

    @incentive_rule.setter
    def incentive_rule(self, value):
        self._incentive_rule = value
    @property
    def max_incentive_count(self):
        return self._max_incentive_count

    @max_incentive_count.setter
    def max_incentive_count(self, value):
        self._max_incentive_count = value
    @property
    def published_point_amount(self):
        return self._published_point_amount

    @published_point_amount.setter
    def published_point_amount(self, value):
        self._published_point_amount = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def target_indicator(self):
        return self._target_indicator

    @target_indicator.setter
    def target_indicator(self, value):
        self._target_indicator = value
    @property
    def task_end_time(self):
        return self._task_end_time

    @task_end_time.setter
    def task_end_time(self, value):
        self._task_end_time = value
    @property
    def task_instance_id(self):
        return self._task_instance_id

    @task_instance_id.setter
    def task_instance_id(self, value):
        self._task_instance_id = value
    @property
    def task_logo(self):
        return self._task_logo

    @task_logo.setter
    def task_logo(self, value):
        self._task_logo = value
    @property
    def task_name(self):
        return self._task_name

    @task_name.setter
    def task_name(self, value):
        self._task_name = value
    @property
    def task_start_time(self):
        return self._task_start_time

    @task_start_time.setter
    def task_start_time(self, value):
        self._task_start_time = value
    @property
    def task_template_id(self):
        return self._task_template_id

    @task_template_id.setter
    def task_template_id(self, value):
        self._task_template_id = value
    @property
    def task_type(self):
        return self._task_type

    @task_type.setter
    def task_type(self, value):
        self._task_type = value
    @property
    def total_point_amount(self):
        return self._total_point_amount

    @total_point_amount.setter
    def total_point_amount(self, value):
        self._total_point_amount = value
    @property
    def unexchange_point_amount(self):
        return self._unexchange_point_amount

    @unexchange_point_amount.setter
    def unexchange_point_amount(self, value):
        self._unexchange_point_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_indicator:
            if hasattr(self.current_indicator, 'to_alipay_dict'):
                params['current_indicator'] = self.current_indicator.to_alipay_dict()
            else:
                params['current_indicator'] = self.current_indicator
        if self.incentive_mode:
            if hasattr(self.incentive_mode, 'to_alipay_dict'):
                params['incentive_mode'] = self.incentive_mode.to_alipay_dict()
            else:
                params['incentive_mode'] = self.incentive_mode
        if self.incentive_rule:
            if hasattr(self.incentive_rule, 'to_alipay_dict'):
                params['incentive_rule'] = self.incentive_rule.to_alipay_dict()
            else:
                params['incentive_rule'] = self.incentive_rule
        if self.max_incentive_count:
            if hasattr(self.max_incentive_count, 'to_alipay_dict'):
                params['max_incentive_count'] = self.max_incentive_count.to_alipay_dict()
            else:
                params['max_incentive_count'] = self.max_incentive_count
        if self.published_point_amount:
            if hasattr(self.published_point_amount, 'to_alipay_dict'):
                params['published_point_amount'] = self.published_point_amount.to_alipay_dict()
            else:
                params['published_point_amount'] = self.published_point_amount
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.target_indicator:
            if hasattr(self.target_indicator, 'to_alipay_dict'):
                params['target_indicator'] = self.target_indicator.to_alipay_dict()
            else:
                params['target_indicator'] = self.target_indicator
        if self.task_end_time:
            if hasattr(self.task_end_time, 'to_alipay_dict'):
                params['task_end_time'] = self.task_end_time.to_alipay_dict()
            else:
                params['task_end_time'] = self.task_end_time
        if self.task_instance_id:
            if hasattr(self.task_instance_id, 'to_alipay_dict'):
                params['task_instance_id'] = self.task_instance_id.to_alipay_dict()
            else:
                params['task_instance_id'] = self.task_instance_id
        if self.task_logo:
            if hasattr(self.task_logo, 'to_alipay_dict'):
                params['task_logo'] = self.task_logo.to_alipay_dict()
            else:
                params['task_logo'] = self.task_logo
        if self.task_name:
            if hasattr(self.task_name, 'to_alipay_dict'):
                params['task_name'] = self.task_name.to_alipay_dict()
            else:
                params['task_name'] = self.task_name
        if self.task_start_time:
            if hasattr(self.task_start_time, 'to_alipay_dict'):
                params['task_start_time'] = self.task_start_time.to_alipay_dict()
            else:
                params['task_start_time'] = self.task_start_time
        if self.task_template_id:
            if hasattr(self.task_template_id, 'to_alipay_dict'):
                params['task_template_id'] = self.task_template_id.to_alipay_dict()
            else:
                params['task_template_id'] = self.task_template_id
        if self.task_type:
            if hasattr(self.task_type, 'to_alipay_dict'):
                params['task_type'] = self.task_type.to_alipay_dict()
            else:
                params['task_type'] = self.task_type
        if self.total_point_amount:
            if hasattr(self.total_point_amount, 'to_alipay_dict'):
                params['total_point_amount'] = self.total_point_amount.to_alipay_dict()
            else:
                params['total_point_amount'] = self.total_point_amount
        if self.unexchange_point_amount:
            if hasattr(self.unexchange_point_amount, 'to_alipay_dict'):
                params['unexchange_point_amount'] = self.unexchange_point_amount.to_alipay_dict()
            else:
                params['unexchange_point_amount'] = self.unexchange_point_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskInstanceInfo()
        if 'current_indicator' in d:
            o.current_indicator = d['current_indicator']
        if 'incentive_mode' in d:
            o.incentive_mode = d['incentive_mode']
        if 'incentive_rule' in d:
            o.incentive_rule = d['incentive_rule']
        if 'max_incentive_count' in d:
            o.max_incentive_count = d['max_incentive_count']
        if 'published_point_amount' in d:
            o.published_point_amount = d['published_point_amount']
        if 'status' in d:
            o.status = d['status']
        if 'target_indicator' in d:
            o.target_indicator = d['target_indicator']
        if 'task_end_time' in d:
            o.task_end_time = d['task_end_time']
        if 'task_instance_id' in d:
            o.task_instance_id = d['task_instance_id']
        if 'task_logo' in d:
            o.task_logo = d['task_logo']
        if 'task_name' in d:
            o.task_name = d['task_name']
        if 'task_start_time' in d:
            o.task_start_time = d['task_start_time']
        if 'task_template_id' in d:
            o.task_template_id = d['task_template_id']
        if 'task_type' in d:
            o.task_type = d['task_type']
        if 'total_point_amount' in d:
            o.total_point_amount = d['total_point_amount']
        if 'unexchange_point_amount' in d:
            o.unexchange_point_amount = d['unexchange_point_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CertAvailableNumVO import CertAvailableNumVO


class AlipayMarketingToolCertNumQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingToolCertNumQueryResponse, self).__init__()
        self._cert_available_num = None

    @property
    def cert_available_num(self):
        return self._cert_available_num

    @cert_available_num.setter
    def cert_available_num(self, value):
        if isinstance(value, list):
            self._cert_available_num = list()
            for i in value:
                if isinstance(i, CertAvailableNumVO):
                    self._cert_available_num.append(i)
                else:
                    self._cert_available_num.append(CertAvailableNumVO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingToolCertNumQueryResponse, self).parse_response_content(response_content)
        if 'cert_available_num' in response:
            self.cert_available_num = response['cert_available_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditSupplychainWfRepaymentdetailQueryModel(object):

    def __init__(self):
        self._billno = None
        self._pagenum = None
        self._pagesize = None
        self._scene = None
        self._sellerid = None
        self._site = None
        self._siteuserid = None

    @property
    def billno(self):
        return self._billno

    @billno.setter
    def billno(self, value):
        self._billno = value
    @property
    def pagenum(self):
        return self._pagenum

    @pagenum.setter
    def pagenum(self, value):
        self._pagenum = value
    @property
    def pagesize(self):
        return self._pagesize

    @pagesize.setter
    def pagesize(self, value):
        self._pagesize = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def sellerid(self):
        return self._sellerid

    @sellerid.setter
    def sellerid(self, value):
        self._sellerid = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def siteuserid(self):
        return self._siteuserid

    @siteuserid.setter
    def siteuserid(self, value):
        self._siteuserid = value


    def to_alipay_dict(self):
        params = dict()
        if self.billno:
            if hasattr(self.billno, 'to_alipay_dict'):
                params['billno'] = self.billno.to_alipay_dict()
            else:
                params['billno'] = self.billno
        if self.pagenum:
            if hasattr(self.pagenum, 'to_alipay_dict'):
                params['pagenum'] = self.pagenum.to_alipay_dict()
            else:
                params['pagenum'] = self.pagenum
        if self.pagesize:
            if hasattr(self.pagesize, 'to_alipay_dict'):
                params['pagesize'] = self.pagesize.to_alipay_dict()
            else:
                params['pagesize'] = self.pagesize
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.sellerid:
            if hasattr(self.sellerid, 'to_alipay_dict'):
                params['sellerid'] = self.sellerid.to_alipay_dict()
            else:
                params['sellerid'] = self.sellerid
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.siteuserid:
            if hasattr(self.siteuserid, 'to_alipay_dict'):
                params['siteuserid'] = self.siteuserid.to_alipay_dict()
            else:
                params['siteuserid'] = self.siteuserid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainWfRepaymentdetailQueryModel()
        if 'billno' in d:
            o.billno = d['billno']
        if 'pagenum' in d:
            o.pagenum = d['pagenum']
        if 'pagesize' in d:
            o.pagesize = d['pagesize']
        if 'scene' in d:
            o.scene = d['scene']
        if 'sellerid' in d:
            o.sellerid = d['sellerid']
        if 'site' in d:
            o.site = d['site']
        if 'siteuserid' in d:
            o.siteuserid = d['siteuserid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TuitionUserName import TuitionUserName


class TuitionCertificate(object):

    def __init__(self):
        self._certificate_no = None
        self._certificate_type = None
        self._effective_date = None
        self._expire_date = None
        self._holder_name = None

    @property
    def certificate_no(self):
        return self._certificate_no

    @certificate_no.setter
    def certificate_no(self, value):
        self._certificate_no = value
    @property
    def certificate_type(self):
        return self._certificate_type

    @certificate_type.setter
    def certificate_type(self, value):
        self._certificate_type = value
    @property
    def effective_date(self):
        return self._effective_date

    @effective_date.setter
    def effective_date(self, value):
        self._effective_date = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def holder_name(self):
        return self._holder_name

    @holder_name.setter
    def holder_name(self, value):
        if isinstance(value, TuitionUserName):
            self._holder_name = value
        else:
            self._holder_name = TuitionUserName.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.certificate_no:
            if hasattr(self.certificate_no, 'to_alipay_dict'):
                params['certificate_no'] = self.certificate_no.to_alipay_dict()
            else:
                params['certificate_no'] = self.certificate_no
        if self.certificate_type:
            if hasattr(self.certificate_type, 'to_alipay_dict'):
                params['certificate_type'] = self.certificate_type.to_alipay_dict()
            else:
                params['certificate_type'] = self.certificate_type
        if self.effective_date:
            if hasattr(self.effective_date, 'to_alipay_dict'):
                params['effective_date'] = self.effective_date.to_alipay_dict()
            else:
                params['effective_date'] = self.effective_date
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.holder_name:
            if hasattr(self.holder_name, 'to_alipay_dict'):
                params['holder_name'] = self.holder_name.to_alipay_dict()
            else:
                params['holder_name'] = self.holder_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TuitionCertificate()
        if 'certificate_no' in d:
            o.certificate_no = d['certificate_no']
        if 'certificate_type' in d:
            o.certificate_type = d['certificate_type']
        if 'effective_date' in d:
            o.effective_date = d['effective_date']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'holder_name' in d:
            o.holder_name = d['holder_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ClaimStrategy import ClaimStrategy
from alipay.aop.api.domain.InsOrderInfo import InsOrderInfo


class AlipayInsSceneApplicationOrderapplyCreateModel(object):

    def __init__(self):
        self._biz_data = None
        self._claim_strategy_list = None
        self._havana_id = None
        self._order_info = None
        self._out_biz_no = None
        self._policy_no = None
        self._prod_code = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def claim_strategy_list(self):
        return self._claim_strategy_list

    @claim_strategy_list.setter
    def claim_strategy_list(self, value):
        if isinstance(value, list):
            self._claim_strategy_list = list()
            for i in value:
                if isinstance(i, ClaimStrategy):
                    self._claim_strategy_list.append(i)
                else:
                    self._claim_strategy_list.append(ClaimStrategy.from_alipay_dict(i))
    @property
    def havana_id(self):
        return self._havana_id

    @havana_id.setter
    def havana_id(self, value):
        self._havana_id = value
    @property
    def order_info(self):
        return self._order_info

    @order_info.setter
    def order_info(self, value):
        if isinstance(value, InsOrderInfo):
            self._order_info = value
        else:
            self._order_info = InsOrderInfo.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.claim_strategy_list:
            if isinstance(self.claim_strategy_list, list):
                for i in range(0, len(self.claim_strategy_list)):
                    element = self.claim_strategy_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.claim_strategy_list[i] = element.to_alipay_dict()
            if hasattr(self.claim_strategy_list, 'to_alipay_dict'):
                params['claim_strategy_list'] = self.claim_strategy_list.to_alipay_dict()
            else:
                params['claim_strategy_list'] = self.claim_strategy_list
        if self.havana_id:
            if hasattr(self.havana_id, 'to_alipay_dict'):
                params['havana_id'] = self.havana_id.to_alipay_dict()
            else:
                params['havana_id'] = self.havana_id
        if self.order_info:
            if hasattr(self.order_info, 'to_alipay_dict'):
                params['order_info'] = self.order_info.to_alipay_dict()
            else:
                params['order_info'] = self.order_info
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneApplicationOrderapplyCreateModel()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'claim_strategy_list' in d:
            o.claim_strategy_list = d['claim_strategy_list']
        if 'havana_id' in d:
            o.havana_id = d['havana_id']
        if 'order_info' in d:
            o.order_info = d['order_info']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MorphoIdentity import MorphoIdentity


class AlipayOpenMiniMorphoAppauditCancelModel(object):

    def __init__(self):
        self._app_version = None
        self._id = None
        self._identity = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        if isinstance(value, MorphoIdentity):
            self._identity = value
        else:
            self._identity = MorphoIdentity.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniMorphoAppauditCancelModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'id' in d:
            o.id = d['id']
        if 'identity' in d:
            o.identity = d['identity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OnlineInviteNewerSummaryInfo(object):

    def __init__(self):
        self._ext_info = None
        self._partner_id = None
        self._pid = None
        self._report_date = None
        self._user_bind_card_count = None
        self._user_cert_settle_count = None
        self._user_new_settle_count = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def user_bind_card_count(self):
        return self._user_bind_card_count

    @user_bind_card_count.setter
    def user_bind_card_count(self, value):
        self._user_bind_card_count = value
    @property
    def user_cert_settle_count(self):
        return self._user_cert_settle_count

    @user_cert_settle_count.setter
    def user_cert_settle_count(self, value):
        self._user_cert_settle_count = value
    @property
    def user_new_settle_count(self):
        return self._user_new_settle_count

    @user_new_settle_count.setter
    def user_new_settle_count(self, value):
        self._user_new_settle_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.user_bind_card_count:
            if hasattr(self.user_bind_card_count, 'to_alipay_dict'):
                params['user_bind_card_count'] = self.user_bind_card_count.to_alipay_dict()
            else:
                params['user_bind_card_count'] = self.user_bind_card_count
        if self.user_cert_settle_count:
            if hasattr(self.user_cert_settle_count, 'to_alipay_dict'):
                params['user_cert_settle_count'] = self.user_cert_settle_count.to_alipay_dict()
            else:
                params['user_cert_settle_count'] = self.user_cert_settle_count
        if self.user_new_settle_count:
            if hasattr(self.user_new_settle_count, 'to_alipay_dict'):
                params['user_new_settle_count'] = self.user_new_settle_count.to_alipay_dict()
            else:
                params['user_new_settle_count'] = self.user_new_settle_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OnlineInviteNewerSummaryInfo()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pid' in d:
            o.pid = d['pid']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'user_bind_card_count' in d:
            o.user_bind_card_count = d['user_bind_card_count']
        if 'user_cert_settle_count' in d:
            o.user_cert_settle_count = d['user_cert_settle_count']
        if 'user_new_settle_count' in d:
            o.user_new_settle_count = d['user_new_settle_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingActivityOrdervoucherCodedepositResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityOrdervoucherCodedepositResponse, self).__init__()
        self._fail_count = None
        self._success_count = None

    @property
    def fail_count(self):
        return self._fail_count

    @fail_count.setter
    def fail_count(self, value):
        self._fail_count = value
    @property
    def success_count(self):
        return self._success_count

    @success_count.setter
    def success_count(self, value):
        self._success_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityOrdervoucherCodedepositResponse, self).parse_response_content(response_content)
        if 'fail_count' in response:
            self.fail_count = response['fail_count']
        if 'success_count' in response:
            self.success_count = response['success_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateFacefeatureFileApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateFacefeatureFileApplyResponse, self).__init__()
        self._download_url = None
        self._file_date = None
        self._file_name = None
        self._file_status = None

    @property
    def download_url(self):
        return self._download_url

    @download_url.setter
    def download_url(self, value):
        self._download_url = value
    @property
    def file_date(self):
        return self._file_date

    @file_date.setter
    def file_date(self, value):
        self._file_date = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_status(self):
        return self._file_status

    @file_status.setter
    def file_status(self, value):
        self._file_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateFacefeatureFileApplyResponse, self).parse_response_content(response_content)
        if 'download_url' in response:
            self.download_url = response['download_url']
        if 'file_date' in response:
            self.file_date = response['file_date']
        if 'file_name' in response:
            self.file_name = response['file_name']
        if 'file_status' in response:
            self.file_status = response['file_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BcClusterMsgRecord(object):

    def __init__(self):
        self._biz_id = None
        self._msg_name = None
        self._send_cluster_ids = None
        self._send_time = None
        self._status = None
        self._template_code = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def msg_name(self):
        return self._msg_name

    @msg_name.setter
    def msg_name(self, value):
        self._msg_name = value
    @property
    def send_cluster_ids(self):
        return self._send_cluster_ids

    @send_cluster_ids.setter
    def send_cluster_ids(self, value):
        if isinstance(value, list):
            self._send_cluster_ids = list()
            for i in value:
                self._send_cluster_ids.append(i)
    @property
    def send_time(self):
        return self._send_time

    @send_time.setter
    def send_time(self, value):
        self._send_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.msg_name:
            if hasattr(self.msg_name, 'to_alipay_dict'):
                params['msg_name'] = self.msg_name.to_alipay_dict()
            else:
                params['msg_name'] = self.msg_name
        if self.send_cluster_ids:
            if isinstance(self.send_cluster_ids, list):
                for i in range(0, len(self.send_cluster_ids)):
                    element = self.send_cluster_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.send_cluster_ids[i] = element.to_alipay_dict()
            if hasattr(self.send_cluster_ids, 'to_alipay_dict'):
                params['send_cluster_ids'] = self.send_cluster_ids.to_alipay_dict()
            else:
                params['send_cluster_ids'] = self.send_cluster_ids
        if self.send_time:
            if hasattr(self.send_time, 'to_alipay_dict'):
                params['send_time'] = self.send_time.to_alipay_dict()
            else:
                params['send_time'] = self.send_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BcClusterMsgRecord()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'msg_name' in d:
            o.msg_name = d['msg_name']
        if 'send_cluster_ids' in d:
            o.send_cluster_ids = d['send_cluster_ids']
        if 'send_time' in d:
            o.send_time = d['send_time']
        if 'status' in d:
            o.status = d['status']
        if 'template_code' in d:
            o.template_code = d['template_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class WriteOffProcessDetailResponseOpenApiDTO(object):

    def __init__(self):
        self._bill_no = None
        self._ip_role_id = None
        self._opposite_bill_no = None
        self._opposite_writeoffable_bill_type = None
        self._writeoff_amt = None
        self._writeoffable_bill_type = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def opposite_bill_no(self):
        return self._opposite_bill_no

    @opposite_bill_no.setter
    def opposite_bill_no(self, value):
        self._opposite_bill_no = value
    @property
    def opposite_writeoffable_bill_type(self):
        return self._opposite_writeoffable_bill_type

    @opposite_writeoffable_bill_type.setter
    def opposite_writeoffable_bill_type(self, value):
        self._opposite_writeoffable_bill_type = value
    @property
    def writeoff_amt(self):
        return self._writeoff_amt

    @writeoff_amt.setter
    def writeoff_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._writeoff_amt = value
        else:
            self._writeoff_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def writeoffable_bill_type(self):
        return self._writeoffable_bill_type

    @writeoffable_bill_type.setter
    def writeoffable_bill_type(self, value):
        self._writeoffable_bill_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.opposite_bill_no:
            if hasattr(self.opposite_bill_no, 'to_alipay_dict'):
                params['opposite_bill_no'] = self.opposite_bill_no.to_alipay_dict()
            else:
                params['opposite_bill_no'] = self.opposite_bill_no
        if self.opposite_writeoffable_bill_type:
            if hasattr(self.opposite_writeoffable_bill_type, 'to_alipay_dict'):
                params['opposite_writeoffable_bill_type'] = self.opposite_writeoffable_bill_type.to_alipay_dict()
            else:
                params['opposite_writeoffable_bill_type'] = self.opposite_writeoffable_bill_type
        if self.writeoff_amt:
            if hasattr(self.writeoff_amt, 'to_alipay_dict'):
                params['writeoff_amt'] = self.writeoff_amt.to_alipay_dict()
            else:
                params['writeoff_amt'] = self.writeoff_amt
        if self.writeoffable_bill_type:
            if hasattr(self.writeoffable_bill_type, 'to_alipay_dict'):
                params['writeoffable_bill_type'] = self.writeoffable_bill_type.to_alipay_dict()
            else:
                params['writeoffable_bill_type'] = self.writeoffable_bill_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WriteOffProcessDetailResponseOpenApiDTO()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'opposite_bill_no' in d:
            o.opposite_bill_no = d['opposite_bill_no']
        if 'opposite_writeoffable_bill_type' in d:
            o.opposite_writeoffable_bill_type = d['opposite_writeoffable_bill_type']
        if 'writeoff_amt' in d:
            o.writeoff_amt = d['writeoff_amt']
        if 'writeoffable_bill_type' in d:
            o.writeoffable_bill_type = d['writeoffable_bill_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFincoreComplianceRcsmartRuleQueryModel(object):

    def __init__(self):
        self._app_name = None
        self._app_token = None
        self._file_id = None
        self._request_id = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_token(self):
        return self._app_token

    @app_token.setter
    def app_token(self, value):
        self._app_token = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_token:
            if hasattr(self.app_token, 'to_alipay_dict'):
                params['app_token'] = self.app_token.to_alipay_dict()
            else:
                params['app_token'] = self.app_token
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceRcsmartRuleQueryModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_token' in d:
            o.app_token = d['app_token']
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetResult import AssetResult


class AntMerchantExpandAssetdeliveryAssignSyncModel(object):

    def __init__(self):
        self._delivery_results = None

    @property
    def delivery_results(self):
        return self._delivery_results

    @delivery_results.setter
    def delivery_results(self, value):
        if isinstance(value, list):
            self._delivery_results = list()
            for i in value:
                if isinstance(i, AssetResult):
                    self._delivery_results.append(i)
                else:
                    self._delivery_results.append(AssetResult.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_results:
            if isinstance(self.delivery_results, list):
                for i in range(0, len(self.delivery_results)):
                    element = self.delivery_results[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.delivery_results[i] = element.to_alipay_dict()
            if hasattr(self.delivery_results, 'to_alipay_dict'):
                params['delivery_results'] = self.delivery_results.to_alipay_dict()
            else:
                params['delivery_results'] = self.delivery_results
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandAssetdeliveryAssignSyncModel()
        if 'delivery_results' in d:
            o.delivery_results = d['delivery_results']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PaymentVoucherAlipayBalanceRechargeInfo import PaymentVoucherAlipayBalanceRechargeInfo


class PaymentVoucherRechargeInfo(object):

    def __init__(self):
        self._alipay_balance_recharge_info = None
        self._recharge_type = None

    @property
    def alipay_balance_recharge_info(self):
        return self._alipay_balance_recharge_info

    @alipay_balance_recharge_info.setter
    def alipay_balance_recharge_info(self, value):
        if isinstance(value, PaymentVoucherAlipayBalanceRechargeInfo):
            self._alipay_balance_recharge_info = value
        else:
            self._alipay_balance_recharge_info = PaymentVoucherAlipayBalanceRechargeInfo.from_alipay_dict(value)
    @property
    def recharge_type(self):
        return self._recharge_type

    @recharge_type.setter
    def recharge_type(self, value):
        self._recharge_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_balance_recharge_info:
            if hasattr(self.alipay_balance_recharge_info, 'to_alipay_dict'):
                params['alipay_balance_recharge_info'] = self.alipay_balance_recharge_info.to_alipay_dict()
            else:
                params['alipay_balance_recharge_info'] = self.alipay_balance_recharge_info
        if self.recharge_type:
            if hasattr(self.recharge_type, 'to_alipay_dict'):
                params['recharge_type'] = self.recharge_type.to_alipay_dict()
            else:
                params['recharge_type'] = self.recharge_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentVoucherRechargeInfo()
        if 'alipay_balance_recharge_info' in d:
            o.alipay_balance_recharge_info = d['alipay_balance_recharge_info']
        if 'recharge_type' in d:
            o.recharge_type = d['recharge_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserDeliverAddress(object):

    def __init__(self):
        self._address = None
        self._address_code = None
        self._default_deliver_address = None
        self._deliver_area = None
        self._deliver_city = None
        self._deliver_fullname = None
        self._deliver_mobile = None
        self._deliver_phone = None
        self._deliver_province = None
        self._zip = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def address_code(self):
        return self._address_code

    @address_code.setter
    def address_code(self, value):
        self._address_code = value
    @property
    def default_deliver_address(self):
        return self._default_deliver_address

    @default_deliver_address.setter
    def default_deliver_address(self, value):
        self._default_deliver_address = value
    @property
    def deliver_area(self):
        return self._deliver_area

    @deliver_area.setter
    def deliver_area(self, value):
        self._deliver_area = value
    @property
    def deliver_city(self):
        return self._deliver_city

    @deliver_city.setter
    def deliver_city(self, value):
        self._deliver_city = value
    @property
    def deliver_fullname(self):
        return self._deliver_fullname

    @deliver_fullname.setter
    def deliver_fullname(self, value):
        self._deliver_fullname = value
    @property
    def deliver_mobile(self):
        return self._deliver_mobile

    @deliver_mobile.setter
    def deliver_mobile(self, value):
        self._deliver_mobile = value
    @property
    def deliver_phone(self):
        return self._deliver_phone

    @deliver_phone.setter
    def deliver_phone(self, value):
        self._deliver_phone = value
    @property
    def deliver_province(self):
        return self._deliver_province

    @deliver_province.setter
    def deliver_province(self, value):
        self._deliver_province = value
    @property
    def zip(self):
        return self._zip

    @zip.setter
    def zip(self, value):
        self._zip = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.address_code:
            if hasattr(self.address_code, 'to_alipay_dict'):
                params['address_code'] = self.address_code.to_alipay_dict()
            else:
                params['address_code'] = self.address_code
        if self.default_deliver_address:
            if hasattr(self.default_deliver_address, 'to_alipay_dict'):
                params['default_deliver_address'] = self.default_deliver_address.to_alipay_dict()
            else:
                params['default_deliver_address'] = self.default_deliver_address
        if self.deliver_area:
            if hasattr(self.deliver_area, 'to_alipay_dict'):
                params['deliver_area'] = self.deliver_area.to_alipay_dict()
            else:
                params['deliver_area'] = self.deliver_area
        if self.deliver_city:
            if hasattr(self.deliver_city, 'to_alipay_dict'):
                params['deliver_city'] = self.deliver_city.to_alipay_dict()
            else:
                params['deliver_city'] = self.deliver_city
        if self.deliver_fullname:
            if hasattr(self.deliver_fullname, 'to_alipay_dict'):
                params['deliver_fullname'] = self.deliver_fullname.to_alipay_dict()
            else:
                params['deliver_fullname'] = self.deliver_fullname
        if self.deliver_mobile:
            if hasattr(self.deliver_mobile, 'to_alipay_dict'):
                params['deliver_mobile'] = self.deliver_mobile.to_alipay_dict()
            else:
                params['deliver_mobile'] = self.deliver_mobile
        if self.deliver_phone:
            if hasattr(self.deliver_phone, 'to_alipay_dict'):
                params['deliver_phone'] = self.deliver_phone.to_alipay_dict()
            else:
                params['deliver_phone'] = self.deliver_phone
        if self.deliver_province:
            if hasattr(self.deliver_province, 'to_alipay_dict'):
                params['deliver_province'] = self.deliver_province.to_alipay_dict()
            else:
                params['deliver_province'] = self.deliver_province
        if self.zip:
            if hasattr(self.zip, 'to_alipay_dict'):
                params['zip'] = self.zip.to_alipay_dict()
            else:
                params['zip'] = self.zip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserDeliverAddress()
        if 'address' in d:
            o.address = d['address']
        if 'address_code' in d:
            o.address_code = d['address_code']
        if 'default_deliver_address' in d:
            o.default_deliver_address = d['default_deliver_address']
        if 'deliver_area' in d:
            o.deliver_area = d['deliver_area']
        if 'deliver_city' in d:
            o.deliver_city = d['deliver_city']
        if 'deliver_fullname' in d:
            o.deliver_fullname = d['deliver_fullname']
        if 'deliver_mobile' in d:
            o.deliver_mobile = d['deliver_mobile']
        if 'deliver_phone' in d:
            o.deliver_phone = d['deliver_phone']
        if 'deliver_province' in d:
            o.deliver_province = d['deliver_province']
        if 'zip' in d:
            o.zip = d['zip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PrincipalForOpenapi import PrincipalForOpenapi
from alipay.aop.api.domain.ContentObjectRelationForOpenapi import ContentObjectRelationForOpenapi
from alipay.aop.api.domain.ContentExtensionForOpenapi import ContentExtensionForOpenapi
from alipay.aop.api.domain.LabelForOpenapi import LabelForOpenapi


class KoubeiContentContentinfoModifyModel(object):

    def __init__(self):
        self._action_url = None
        self._author = None
        self._biz_type = None
        self._content_desc = None
        self._content_id = None
        self._content_object_relation_list = None
        self._content_type = None
        self._cover_pics = None
        self._ext_info = None
        self._extensions = None
        self._external_id = None
        self._label_list = None
        self._request_token = None
        self._status = None
        self._sub_title = None
        self._title = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def author(self):
        return self._author

    @author.setter
    def author(self, value):
        if isinstance(value, PrincipalForOpenapi):
            self._author = value
        else:
            self._author = PrincipalForOpenapi.from_alipay_dict(value)
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def content_desc(self):
        return self._content_desc

    @content_desc.setter
    def content_desc(self, value):
        self._content_desc = value
    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def content_object_relation_list(self):
        return self._content_object_relation_list

    @content_object_relation_list.setter
    def content_object_relation_list(self, value):
        if isinstance(value, list):
            self._content_object_relation_list = list()
            for i in value:
                if isinstance(i, ContentObjectRelationForOpenapi):
                    self._content_object_relation_list.append(i)
                else:
                    self._content_object_relation_list.append(ContentObjectRelationForOpenapi.from_alipay_dict(i))
    @property
    def content_type(self):
        return self._content_type

    @content_type.setter
    def content_type(self, value):
        self._content_type = value
    @property
    def cover_pics(self):
        return self._cover_pics

    @cover_pics.setter
    def cover_pics(self, value):
        if isinstance(value, list):
            self._cover_pics = list()
            for i in value:
                self._cover_pics.append(i)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def extensions(self):
        return self._extensions

    @extensions.setter
    def extensions(self, value):
        if isinstance(value, list):
            self._extensions = list()
            for i in value:
                if isinstance(i, ContentExtensionForOpenapi):
                    self._extensions.append(i)
                else:
                    self._extensions.append(ContentExtensionForOpenapi.from_alipay_dict(i))
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def label_list(self):
        return self._label_list

    @label_list.setter
    def label_list(self, value):
        if isinstance(value, list):
            self._label_list = list()
            for i in value:
                if isinstance(i, LabelForOpenapi):
                    self._label_list.append(i)
                else:
                    self._label_list.append(LabelForOpenapi.from_alipay_dict(i))
    @property
    def request_token(self):
        return self._request_token

    @request_token.setter
    def request_token(self, value):
        self._request_token = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.author:
            if hasattr(self.author, 'to_alipay_dict'):
                params['author'] = self.author.to_alipay_dict()
            else:
                params['author'] = self.author
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.content_desc:
            if hasattr(self.content_desc, 'to_alipay_dict'):
                params['content_desc'] = self.content_desc.to_alipay_dict()
            else:
                params['content_desc'] = self.content_desc
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.content_object_relation_list:
            if isinstance(self.content_object_relation_list, list):
                for i in range(0, len(self.content_object_relation_list)):
                    element = self.content_object_relation_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.content_object_relation_list[i] = element.to_alipay_dict()
            if hasattr(self.content_object_relation_list, 'to_alipay_dict'):
                params['content_object_relation_list'] = self.content_object_relation_list.to_alipay_dict()
            else:
                params['content_object_relation_list'] = self.content_object_relation_list
        if self.content_type:
            if hasattr(self.content_type, 'to_alipay_dict'):
                params['content_type'] = self.content_type.to_alipay_dict()
            else:
                params['content_type'] = self.content_type
        if self.cover_pics:
            if isinstance(self.cover_pics, list):
                for i in range(0, len(self.cover_pics)):
                    element = self.cover_pics[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cover_pics[i] = element.to_alipay_dict()
            if hasattr(self.cover_pics, 'to_alipay_dict'):
                params['cover_pics'] = self.cover_pics.to_alipay_dict()
            else:
                params['cover_pics'] = self.cover_pics
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.extensions:
            if isinstance(self.extensions, list):
                for i in range(0, len(self.extensions)):
                    element = self.extensions[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.extensions[i] = element.to_alipay_dict()
            if hasattr(self.extensions, 'to_alipay_dict'):
                params['extensions'] = self.extensions.to_alipay_dict()
            else:
                params['extensions'] = self.extensions
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.label_list:
            if isinstance(self.label_list, list):
                for i in range(0, len(self.label_list)):
                    element = self.label_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.label_list[i] = element.to_alipay_dict()
            if hasattr(self.label_list, 'to_alipay_dict'):
                params['label_list'] = self.label_list.to_alipay_dict()
            else:
                params['label_list'] = self.label_list
        if self.request_token:
            if hasattr(self.request_token, 'to_alipay_dict'):
                params['request_token'] = self.request_token.to_alipay_dict()
            else:
                params['request_token'] = self.request_token
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiContentContentinfoModifyModel()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'author' in d:
            o.author = d['author']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'content_desc' in d:
            o.content_desc = d['content_desc']
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'content_object_relation_list' in d:
            o.content_object_relation_list = d['content_object_relation_list']
        if 'content_type' in d:
            o.content_type = d['content_type']
        if 'cover_pics' in d:
            o.cover_pics = d['cover_pics']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'extensions' in d:
            o.extensions = d['extensions']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'label_list' in d:
            o.label_list = d['label_list']
        if 'request_token' in d:
            o.request_token = d['request_token']
        if 'status' in d:
            o.status = d['status']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItermInfo import ItermInfo


class AlipayEbppRechargeItemGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppRechargeItemGetResponse, self).__init__()
        self._error_code = None
        self._error_message = None
        self._iterm_infos = None
        self._success = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def iterm_infos(self):
        return self._iterm_infos

    @iterm_infos.setter
    def iterm_infos(self, value):
        if isinstance(value, list):
            self._iterm_infos = list()
            for i in value:
                if isinstance(i, ItermInfo):
                    self._iterm_infos.append(i)
                else:
                    self._iterm_infos.append(ItermInfo.from_alipay_dict(i))
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppRechargeItemGetResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'iterm_infos' in response:
            self.iterm_infos = response['iterm_infos']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishGroupDetailInfo(object):

    def __init__(self):
        self._add_price = None
        self._detail_count = None
        self._detail_dish_id = None
        self._detail_is_default = None
        self._detail_sku_id = None
        self._detail_sort = None
        self._group_id = None

    @property
    def add_price(self):
        return self._add_price

    @add_price.setter
    def add_price(self, value):
        self._add_price = value
    @property
    def detail_count(self):
        return self._detail_count

    @detail_count.setter
    def detail_count(self, value):
        self._detail_count = value
    @property
    def detail_dish_id(self):
        return self._detail_dish_id

    @detail_dish_id.setter
    def detail_dish_id(self, value):
        self._detail_dish_id = value
    @property
    def detail_is_default(self):
        return self._detail_is_default

    @detail_is_default.setter
    def detail_is_default(self, value):
        self._detail_is_default = value
    @property
    def detail_sku_id(self):
        return self._detail_sku_id

    @detail_sku_id.setter
    def detail_sku_id(self, value):
        self._detail_sku_id = value
    @property
    def detail_sort(self):
        return self._detail_sort

    @detail_sort.setter
    def detail_sort(self, value):
        self._detail_sort = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.add_price:
            if hasattr(self.add_price, 'to_alipay_dict'):
                params['add_price'] = self.add_price.to_alipay_dict()
            else:
                params['add_price'] = self.add_price
        if self.detail_count:
            if hasattr(self.detail_count, 'to_alipay_dict'):
                params['detail_count'] = self.detail_count.to_alipay_dict()
            else:
                params['detail_count'] = self.detail_count
        if self.detail_dish_id:
            if hasattr(self.detail_dish_id, 'to_alipay_dict'):
                params['detail_dish_id'] = self.detail_dish_id.to_alipay_dict()
            else:
                params['detail_dish_id'] = self.detail_dish_id
        if self.detail_is_default:
            if hasattr(self.detail_is_default, 'to_alipay_dict'):
                params['detail_is_default'] = self.detail_is_default.to_alipay_dict()
            else:
                params['detail_is_default'] = self.detail_is_default
        if self.detail_sku_id:
            if hasattr(self.detail_sku_id, 'to_alipay_dict'):
                params['detail_sku_id'] = self.detail_sku_id.to_alipay_dict()
            else:
                params['detail_sku_id'] = self.detail_sku_id
        if self.detail_sort:
            if hasattr(self.detail_sort, 'to_alipay_dict'):
                params['detail_sort'] = self.detail_sort.to_alipay_dict()
            else:
                params['detail_sort'] = self.detail_sort
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishGroupDetailInfo()
        if 'add_price' in d:
            o.add_price = d['add_price']
        if 'detail_count' in d:
            o.detail_count = d['detail_count']
        if 'detail_dish_id' in d:
            o.detail_dish_id = d['detail_dish_id']
        if 'detail_is_default' in d:
            o.detail_is_default = d['detail_is_default']
        if 'detail_sku_id' in d:
            o.detail_sku_id = d['detail_sku_id']
        if 'detail_sort' in d:
            o.detail_sort = d['detail_sort']
        if 'group_id' in d:
            o.group_id = d['group_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCashvoucherTemplateCreateModel(object):

    def __init__(self):
        self._amount = None
        self._brand_name = None
        self._extension_info = None
        self._floor_amount = None
        self._fund_account = None
        self._notify_uri = None
        self._out_biz_no = None
        self._publish_end_time = None
        self._publish_start_time = None
        self._redirect_uri = None
        self._rule_conf = None
        self._slogan = None
        self._voucher_description = None
        self._voucher_quantity = None
        self._voucher_type = None
        self._voucher_use_scene = None
        self._voucher_valid_period = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def extension_info(self):
        return self._extension_info

    @extension_info.setter
    def extension_info(self, value):
        self._extension_info = value
    @property
    def floor_amount(self):
        return self._floor_amount

    @floor_amount.setter
    def floor_amount(self, value):
        self._floor_amount = value
    @property
    def fund_account(self):
        return self._fund_account

    @fund_account.setter
    def fund_account(self, value):
        self._fund_account = value
    @property
    def notify_uri(self):
        return self._notify_uri

    @notify_uri.setter
    def notify_uri(self, value):
        self._notify_uri = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def publish_start_time(self):
        return self._publish_start_time

    @publish_start_time.setter
    def publish_start_time(self, value):
        self._publish_start_time = value
    @property
    def redirect_uri(self):
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, value):
        self._redirect_uri = value
    @property
    def rule_conf(self):
        return self._rule_conf

    @rule_conf.setter
    def rule_conf(self, value):
        self._rule_conf = value
    @property
    def slogan(self):
        return self._slogan

    @slogan.setter
    def slogan(self, value):
        self._slogan = value
    @property
    def voucher_description(self):
        return self._voucher_description

    @voucher_description.setter
    def voucher_description(self, value):
        self._voucher_description = value
    @property
    def voucher_quantity(self):
        return self._voucher_quantity

    @voucher_quantity.setter
    def voucher_quantity(self, value):
        self._voucher_quantity = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value
    @property
    def voucher_use_scene(self):
        return self._voucher_use_scene

    @voucher_use_scene.setter
    def voucher_use_scene(self, value):
        self._voucher_use_scene = value
    @property
    def voucher_valid_period(self):
        return self._voucher_valid_period

    @voucher_valid_period.setter
    def voucher_valid_period(self, value):
        self._voucher_valid_period = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.extension_info:
            if hasattr(self.extension_info, 'to_alipay_dict'):
                params['extension_info'] = self.extension_info.to_alipay_dict()
            else:
                params['extension_info'] = self.extension_info
        if self.floor_amount:
            if hasattr(self.floor_amount, 'to_alipay_dict'):
                params['floor_amount'] = self.floor_amount.to_alipay_dict()
            else:
                params['floor_amount'] = self.floor_amount
        if self.fund_account:
            if hasattr(self.fund_account, 'to_alipay_dict'):
                params['fund_account'] = self.fund_account.to_alipay_dict()
            else:
                params['fund_account'] = self.fund_account
        if self.notify_uri:
            if hasattr(self.notify_uri, 'to_alipay_dict'):
                params['notify_uri'] = self.notify_uri.to_alipay_dict()
            else:
                params['notify_uri'] = self.notify_uri
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.publish_end_time:
            if hasattr(self.publish_end_time, 'to_alipay_dict'):
                params['publish_end_time'] = self.publish_end_time.to_alipay_dict()
            else:
                params['publish_end_time'] = self.publish_end_time
        if self.publish_start_time:
            if hasattr(self.publish_start_time, 'to_alipay_dict'):
                params['publish_start_time'] = self.publish_start_time.to_alipay_dict()
            else:
                params['publish_start_time'] = self.publish_start_time
        if self.redirect_uri:
            if hasattr(self.redirect_uri, 'to_alipay_dict'):
                params['redirect_uri'] = self.redirect_uri.to_alipay_dict()
            else:
                params['redirect_uri'] = self.redirect_uri
        if self.rule_conf:
            if hasattr(self.rule_conf, 'to_alipay_dict'):
                params['rule_conf'] = self.rule_conf.to_alipay_dict()
            else:
                params['rule_conf'] = self.rule_conf
        if self.slogan:
            if hasattr(self.slogan, 'to_alipay_dict'):
                params['slogan'] = self.slogan.to_alipay_dict()
            else:
                params['slogan'] = self.slogan
        if self.voucher_description:
            if hasattr(self.voucher_description, 'to_alipay_dict'):
                params['voucher_description'] = self.voucher_description.to_alipay_dict()
            else:
                params['voucher_description'] = self.voucher_description
        if self.voucher_quantity:
            if hasattr(self.voucher_quantity, 'to_alipay_dict'):
                params['voucher_quantity'] = self.voucher_quantity.to_alipay_dict()
            else:
                params['voucher_quantity'] = self.voucher_quantity
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        if self.voucher_use_scene:
            if hasattr(self.voucher_use_scene, 'to_alipay_dict'):
                params['voucher_use_scene'] = self.voucher_use_scene.to_alipay_dict()
            else:
                params['voucher_use_scene'] = self.voucher_use_scene
        if self.voucher_valid_period:
            if hasattr(self.voucher_valid_period, 'to_alipay_dict'):
                params['voucher_valid_period'] = self.voucher_valid_period.to_alipay_dict()
            else:
                params['voucher_valid_period'] = self.voucher_valid_period
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCashvoucherTemplateCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'extension_info' in d:
            o.extension_info = d['extension_info']
        if 'floor_amount' in d:
            o.floor_amount = d['floor_amount']
        if 'fund_account' in d:
            o.fund_account = d['fund_account']
        if 'notify_uri' in d:
            o.notify_uri = d['notify_uri']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'publish_end_time' in d:
            o.publish_end_time = d['publish_end_time']
        if 'publish_start_time' in d:
            o.publish_start_time = d['publish_start_time']
        if 'redirect_uri' in d:
            o.redirect_uri = d['redirect_uri']
        if 'rule_conf' in d:
            o.rule_conf = d['rule_conf']
        if 'slogan' in d:
            o.slogan = d['slogan']
        if 'voucher_description' in d:
            o.voucher_description = d['voucher_description']
        if 'voucher_quantity' in d:
            o.voucher_quantity = d['voucher_quantity']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        if 'voucher_use_scene' in d:
            o.voucher_use_scene = d['voucher_use_scene']
        if 'voucher_valid_period' in d:
            o.voucher_valid_period = d['voucher_valid_period']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OrderItem import OrderItem


class AlipayOpenServicemarketOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenServicemarketOrderQueryResponse, self).__init__()
        self._commodity_id = None
        self._current_page = None
        self._order_items = None
        self._specifications = None
        self._status = None
        self._total_size = None

    @property
    def commodity_id(self):
        return self._commodity_id

    @commodity_id.setter
    def commodity_id(self, value):
        self._commodity_id = value
    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def order_items(self):
        return self._order_items

    @order_items.setter
    def order_items(self, value):
        if isinstance(value, list):
            self._order_items = list()
            for i in value:
                if isinstance(i, OrderItem):
                    self._order_items.append(i)
                else:
                    self._order_items.append(OrderItem.from_alipay_dict(i))
    @property
    def specifications(self):
        return self._specifications

    @specifications.setter
    def specifications(self, value):
        self._specifications = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenServicemarketOrderQueryResponse, self).parse_response_content(response_content)
        if 'commodity_id' in response:
            self.commodity_id = response['commodity_id']
        if 'current_page' in response:
            self.current_page = response['current_page']
        if 'order_items' in response:
            self.order_items = response['order_items']
        if 'specifications' in response:
            self.specifications = response['specifications']
        if 'status' in response:
            self.status = response['status']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdIfaatamMessagenotifySendResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdIfaatamMessagenotifySendResponse, self).__init__()
        self._return_code = None
        self._return_msg = None
        self._success = None

    @property
    def return_code(self):
        return self._return_code

    @return_code.setter
    def return_code(self, value):
        self._return_code = value
    @property
    def return_msg(self):
        return self._return_msg

    @return_msg.setter
    def return_msg(self, value):
        self._return_msg = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdIfaatamMessagenotifySendResponse, self).parse_response_content(response_content)
        if 'return_code' in response:
            self.return_code = response['return_code']
        if 'return_msg' in response:
            self.return_msg = response['return_msg']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppMiniTemplatemessageSendModel(object):

    def __init__(self):
        self._data = None
        self._form_id = None
        self._page = None
        self._to_user_id = None
        self._user_template_id = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def form_id(self):
        return self._form_id

    @form_id.setter
    def form_id(self, value):
        self._form_id = value
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def to_user_id(self):
        return self._to_user_id

    @to_user_id.setter
    def to_user_id(self, value):
        self._to_user_id = value
    @property
    def user_template_id(self):
        return self._user_template_id

    @user_template_id.setter
    def user_template_id(self, value):
        self._user_template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.form_id:
            if hasattr(self.form_id, 'to_alipay_dict'):
                params['form_id'] = self.form_id.to_alipay_dict()
            else:
                params['form_id'] = self.form_id
        if self.page:
            if hasattr(self.page, 'to_alipay_dict'):
                params['page'] = self.page.to_alipay_dict()
            else:
                params['page'] = self.page
        if self.to_user_id:
            if hasattr(self.to_user_id, 'to_alipay_dict'):
                params['to_user_id'] = self.to_user_id.to_alipay_dict()
            else:
                params['to_user_id'] = self.to_user_id
        if self.user_template_id:
            if hasattr(self.user_template_id, 'to_alipay_dict'):
                params['user_template_id'] = self.user_template_id.to_alipay_dict()
            else:
                params['user_template_id'] = self.user_template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppMiniTemplatemessageSendModel()
        if 'data' in d:
            o.data = d['data']
        if 'form_id' in d:
            o.form_id = d['form_id']
        if 'page' in d:
            o.page = d['page']
        if 'to_user_id' in d:
            o.to_user_id = d['to_user_id']
        if 'user_template_id' in d:
            o.user_template_id = d['user_template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCustomerJobworthInfoQueryModel(object):

    def __init__(self):
        self._back_url = None
        self._cert_no = None
        self._cert_type = None
        self._industry_id = None
        self._job_id = None
        self._user_id = None
        self._user_name = None

    @property
    def back_url(self):
        return self._back_url

    @back_url.setter
    def back_url(self, value):
        self._back_url = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def industry_id(self):
        return self._industry_id

    @industry_id.setter
    def industry_id(self, value):
        self._industry_id = value
    @property
    def job_id(self):
        return self._job_id

    @job_id.setter
    def job_id(self, value):
        self._job_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.back_url:
            if hasattr(self.back_url, 'to_alipay_dict'):
                params['back_url'] = self.back_url.to_alipay_dict()
            else:
                params['back_url'] = self.back_url
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.industry_id:
            if hasattr(self.industry_id, 'to_alipay_dict'):
                params['industry_id'] = self.industry_id.to_alipay_dict()
            else:
                params['industry_id'] = self.industry_id
        if self.job_id:
            if hasattr(self.job_id, 'to_alipay_dict'):
                params['job_id'] = self.job_id.to_alipay_dict()
            else:
                params['job_id'] = self.job_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerJobworthInfoQueryModel()
        if 'back_url' in d:
            o.back_url = d['back_url']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'industry_id' in d:
            o.industry_id = d['industry_id']
        if 'job_id' in d:
            o.job_id = d['job_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataDataserviceAdPrincipalCheckavailableResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAdPrincipalCheckavailableResponse, self).__init__()
        self._principal_id = None
        self._sign_status = None

    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def sign_status(self):
        return self._sign_status

    @sign_status.setter
    def sign_status(self, value):
        self._sign_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAdPrincipalCheckavailableResponse, self).parse_response_content(response_content)
        if 'principal_id' in response:
            self.principal_id = response['principal_id']
        if 'sign_status' in response:
            self.sign_status = response['sign_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundBailOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundBailOrderQueryResponse, self).__init__()
        self._auth_no = None
        self._biz_error = None
        self._fund_entrust_type = None
        self._gmt_create = None
        self._gmt_modified = None
        self._order_status = None
        self._order_title = None
        self._out_order_no = None
        self._product_code = None
        self._rest_amount = None
        self._result_code = None
        self._result_message = None
        self._scene_code = None

    @property
    def auth_no(self):
        return self._auth_no

    @auth_no.setter
    def auth_no(self, value):
        self._auth_no = value
    @property
    def biz_error(self):
        return self._biz_error

    @biz_error.setter
    def biz_error(self, value):
        self._biz_error = value
    @property
    def fund_entrust_type(self):
        return self._fund_entrust_type

    @fund_entrust_type.setter
    def fund_entrust_type(self, value):
        self._fund_entrust_type = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def rest_amount(self):
        return self._rest_amount

    @rest_amount.setter
    def rest_amount(self, value):
        self._rest_amount = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundBailOrderQueryResponse, self).parse_response_content(response_content)
        if 'auth_no' in response:
            self.auth_no = response['auth_no']
        if 'biz_error' in response:
            self.biz_error = response['biz_error']
        if 'fund_entrust_type' in response:
            self.fund_entrust_type = response['fund_entrust_type']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'order_title' in response:
            self.order_title = response['order_title']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'product_code' in response:
            self.product_code = response['product_code']
        if 'rest_amount' in response:
            self.rest_amount = response['rest_amount']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_message' in response:
            self.result_message = response['result_message']
        if 'scene_code' in response:
            self.scene_code = response['scene_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppPdeductSignConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppPdeductSignConfirmResponse, self).__init__()
        self._agreement_id = None
        self._alipay_sign_status = None
        self._rtn_flag = None
        self._rtn_msg = None
        self._serial_no = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def alipay_sign_status(self):
        return self._alipay_sign_status

    @alipay_sign_status.setter
    def alipay_sign_status(self, value):
        self._alipay_sign_status = value
    @property
    def rtn_flag(self):
        return self._rtn_flag

    @rtn_flag.setter
    def rtn_flag(self, value):
        self._rtn_flag = value
    @property
    def rtn_msg(self):
        return self._rtn_msg

    @rtn_msg.setter
    def rtn_msg(self, value):
        self._rtn_msg = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppPdeductSignConfirmResponse, self).parse_response_content(response_content)
        if 'agreement_id' in response:
            self.agreement_id = response['agreement_id']
        if 'alipay_sign_status' in response:
            self.alipay_sign_status = response['alipay_sign_status']
        if 'rtn_flag' in response:
            self.rtn_flag = response['rtn_flag']
        if 'rtn_msg' in response:
            self.rtn_msg = response['rtn_msg']
        if 'serial_no' in response:
            self.serial_no = response['serial_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PaymentAbilityPostbackResponse import PaymentAbilityPostbackResponse


class AlipayDatabizCorePaymentAbilityUpdateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDatabizCorePaymentAbilityUpdateResponse, self).__init__()
        self._payment_ability_postback_response = None

    @property
    def payment_ability_postback_response(self):
        return self._payment_ability_postback_response

    @payment_ability_postback_response.setter
    def payment_ability_postback_response(self, value):
        if isinstance(value, PaymentAbilityPostbackResponse):
            self._payment_ability_postback_response = value
        else:
            self._payment_ability_postback_response = PaymentAbilityPostbackResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayDatabizCorePaymentAbilityUpdateResponse, self).parse_response_content(response_content)
        if 'payment_ability_postback_response' in response:
            self.payment_ability_postback_response = response['payment_ability_postback_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ItemExtInfo import ItemExtInfo
from alipay.aop.api.domain.MaterialModifyInfo import MaterialModifyInfo
from alipay.aop.api.domain.ItemPropertyInfo import ItemPropertyInfo
from alipay.aop.api.domain.SkuModifyInfo import SkuModifyInfo


class AntMerchantExpandItemOpenModifyModel(object):

    def __init__(self):
        self._description = None
        self._ext_info = None
        self._item_id = None
        self._material_list = None
        self._name = None
        self._property_list = None
        self._sku_list = None
        self._standard_category_id = None
        self._status = None
        self._type = None

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, ItemExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(ItemExtInfo.from_alipay_dict(i))
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def material_list(self):
        return self._material_list

    @material_list.setter
    def material_list(self, value):
        if isinstance(value, list):
            self._material_list = list()
            for i in value:
                if isinstance(i, MaterialModifyInfo):
                    self._material_list.append(i)
                else:
                    self._material_list.append(MaterialModifyInfo.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def property_list(self):
        return self._property_list

    @property_list.setter
    def property_list(self, value):
        if isinstance(value, list):
            self._property_list = list()
            for i in value:
                if isinstance(i, ItemPropertyInfo):
                    self._property_list.append(i)
                else:
                    self._property_list.append(ItemPropertyInfo.from_alipay_dict(i))
    @property
    def sku_list(self):
        return self._sku_list

    @sku_list.setter
    def sku_list(self, value):
        if isinstance(value, list):
            self._sku_list = list()
            for i in value:
                if isinstance(i, SkuModifyInfo):
                    self._sku_list.append(i)
                else:
                    self._sku_list.append(SkuModifyInfo.from_alipay_dict(i))
    @property
    def standard_category_id(self):
        return self._standard_category_id

    @standard_category_id.setter
    def standard_category_id(self, value):
        self._standard_category_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.material_list:
            if isinstance(self.material_list, list):
                for i in range(0, len(self.material_list)):
                    element = self.material_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_list[i] = element.to_alipay_dict()
            if hasattr(self.material_list, 'to_alipay_dict'):
                params['material_list'] = self.material_list.to_alipay_dict()
            else:
                params['material_list'] = self.material_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.property_list:
            if isinstance(self.property_list, list):
                for i in range(0, len(self.property_list)):
                    element = self.property_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_list[i] = element.to_alipay_dict()
            if hasattr(self.property_list, 'to_alipay_dict'):
                params['property_list'] = self.property_list.to_alipay_dict()
            else:
                params['property_list'] = self.property_list
        if self.sku_list:
            if isinstance(self.sku_list, list):
                for i in range(0, len(self.sku_list)):
                    element = self.sku_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_list[i] = element.to_alipay_dict()
            if hasattr(self.sku_list, 'to_alipay_dict'):
                params['sku_list'] = self.sku_list.to_alipay_dict()
            else:
                params['sku_list'] = self.sku_list
        if self.standard_category_id:
            if hasattr(self.standard_category_id, 'to_alipay_dict'):
                params['standard_category_id'] = self.standard_category_id.to_alipay_dict()
            else:
                params['standard_category_id'] = self.standard_category_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandItemOpenModifyModel()
        if 'description' in d:
            o.description = d['description']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'material_list' in d:
            o.material_list = d['material_list']
        if 'name' in d:
            o.name = d['name']
        if 'property_list' in d:
            o.property_list = d['property_list']
        if 'sku_list' in d:
            o.sku_list = d['sku_list']
        if 'standard_category_id' in d:
            o.standard_category_id = d['standard_category_id']
        if 'status' in d:
            o.status = d['status']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicPersonalizedMenuDeleteModel(object):

    def __init__(self):
        self._menu_key = None

    @property
    def menu_key(self):
        return self._menu_key

    @menu_key.setter
    def menu_key(self, value):
        self._menu_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.menu_key:
            if hasattr(self.menu_key, 'to_alipay_dict'):
                params['menu_key'] = self.menu_key.to_alipay_dict()
            else:
                params['menu_key'] = self.menu_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicPersonalizedMenuDeleteModel()
        if 'menu_key' in d:
            o.menu_key = d['menu_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPayCodecQrcodecacheAddModel(object):

    def __init__(self):
        self._compress = None
        self._json = None
        self._key = None
        self._time = None
        self._value = None

    @property
    def compress(self):
        return self._compress

    @compress.setter
    def compress(self, value):
        self._compress = value
    @property
    def json(self):
        return self._json

    @json.setter
    def json(self, value):
        if isinstance(value, list):
            self._json = list()
            for i in value:
                self._json.append(i)
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.compress:
            if hasattr(self.compress, 'to_alipay_dict'):
                params['compress'] = self.compress.to_alipay_dict()
            else:
                params['compress'] = self.compress
        if self.json:
            if isinstance(self.json, list):
                for i in range(0, len(self.json)):
                    element = self.json[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.json[i] = element.to_alipay_dict()
            if hasattr(self.json, 'to_alipay_dict'):
                params['json'] = self.json.to_alipay_dict()
            else:
                params['json'] = self.json
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayCodecQrcodecacheAddModel()
        if 'compress' in d:
            o.compress = d['compress']
        if 'json' in d:
            o.json = d['json']
        if 'key' in d:
            o.key = d['key']
        if 'time' in d:
            o.time = d['time']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PointReceiveInfo(object):

    def __init__(self):
        self._msg = None
        self._received_point_amount = None
        self._result = None

    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def received_point_amount(self):
        return self._received_point_amount

    @received_point_amount.setter
    def received_point_amount(self, value):
        self._received_point_amount = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value


    def to_alipay_dict(self):
        params = dict()
        if self.msg:
            if hasattr(self.msg, 'to_alipay_dict'):
                params['msg'] = self.msg.to_alipay_dict()
            else:
                params['msg'] = self.msg
        if self.received_point_amount:
            if hasattr(self.received_point_amount, 'to_alipay_dict'):
                params['received_point_amount'] = self.received_point_amount.to_alipay_dict()
            else:
                params['received_point_amount'] = self.received_point_amount
        if self.result:
            if hasattr(self.result, 'to_alipay_dict'):
                params['result'] = self.result.to_alipay_dict()
            else:
                params['result'] = self.result
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PointReceiveInfo()
        if 'msg' in d:
            o.msg = d['msg']
        if 'received_point_amount' in d:
            o.received_point_amount = d['received_point_amount']
        if 'result' in d:
            o.result = d['result']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PriceInfo import PriceInfo
from alipay.aop.api.domain.ItemCategoryInfo import ItemCategoryInfo


class AlipayBusinessItemExternalSyncModel(object):

    def __init__(self):
        self._end_date = None
        self._ext_price_info = None
        self._ext_prop = None
        self._external_category_info = None
        self._external_item_id = None
        self._inventory = None
        self._item_type = None
        self._original_price = None
        self._picture_info = None
        self._promotion_type = None
        self._request_id = None
        self._start_date = None
        self._status = None
        self._subject = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def ext_price_info(self):
        return self._ext_price_info

    @ext_price_info.setter
    def ext_price_info(self, value):
        if isinstance(value, list):
            self._ext_price_info = list()
            for i in value:
                if isinstance(i, PriceInfo):
                    self._ext_price_info.append(i)
                else:
                    self._ext_price_info.append(PriceInfo.from_alipay_dict(i))
    @property
    def ext_prop(self):
        return self._ext_prop

    @ext_prop.setter
    def ext_prop(self, value):
        self._ext_prop = value
    @property
    def external_category_info(self):
        return self._external_category_info

    @external_category_info.setter
    def external_category_info(self, value):
        if isinstance(value, ItemCategoryInfo):
            self._external_category_info = value
        else:
            self._external_category_info = ItemCategoryInfo.from_alipay_dict(value)
    @property
    def external_item_id(self):
        return self._external_item_id

    @external_item_id.setter
    def external_item_id(self, value):
        self._external_item_id = value
    @property
    def inventory(self):
        return self._inventory

    @inventory.setter
    def inventory(self, value):
        self._inventory = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def picture_info(self):
        return self._picture_info

    @picture_info.setter
    def picture_info(self, value):
        self._picture_info = value
    @property
    def promotion_type(self):
        return self._promotion_type

    @promotion_type.setter
    def promotion_type(self, value):
        self._promotion_type = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.ext_price_info:
            if isinstance(self.ext_price_info, list):
                for i in range(0, len(self.ext_price_info)):
                    element = self.ext_price_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_price_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_price_info, 'to_alipay_dict'):
                params['ext_price_info'] = self.ext_price_info.to_alipay_dict()
            else:
                params['ext_price_info'] = self.ext_price_info
        if self.ext_prop:
            if hasattr(self.ext_prop, 'to_alipay_dict'):
                params['ext_prop'] = self.ext_prop.to_alipay_dict()
            else:
                params['ext_prop'] = self.ext_prop
        if self.external_category_info:
            if hasattr(self.external_category_info, 'to_alipay_dict'):
                params['external_category_info'] = self.external_category_info.to_alipay_dict()
            else:
                params['external_category_info'] = self.external_category_info
        if self.external_item_id:
            if hasattr(self.external_item_id, 'to_alipay_dict'):
                params['external_item_id'] = self.external_item_id.to_alipay_dict()
            else:
                params['external_item_id'] = self.external_item_id
        if self.inventory:
            if hasattr(self.inventory, 'to_alipay_dict'):
                params['inventory'] = self.inventory.to_alipay_dict()
            else:
                params['inventory'] = self.inventory
        if self.item_type:
            if hasattr(self.item_type, 'to_alipay_dict'):
                params['item_type'] = self.item_type.to_alipay_dict()
            else:
                params['item_type'] = self.item_type
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.picture_info:
            if hasattr(self.picture_info, 'to_alipay_dict'):
                params['picture_info'] = self.picture_info.to_alipay_dict()
            else:
                params['picture_info'] = self.picture_info
        if self.promotion_type:
            if hasattr(self.promotion_type, 'to_alipay_dict'):
                params['promotion_type'] = self.promotion_type.to_alipay_dict()
            else:
                params['promotion_type'] = self.promotion_type
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBusinessItemExternalSyncModel()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'ext_price_info' in d:
            o.ext_price_info = d['ext_price_info']
        if 'ext_prop' in d:
            o.ext_prop = d['ext_prop']
        if 'external_category_info' in d:
            o.external_category_info = d['external_category_info']
        if 'external_item_id' in d:
            o.external_item_id = d['external_item_id']
        if 'inventory' in d:
            o.inventory = d['inventory']
        if 'item_type' in d:
            o.item_type = d['item_type']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'picture_info' in d:
            o.picture_info = d['picture_info']
        if 'promotion_type' in d:
            o.promotion_type = d['promotion_type']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'status' in d:
            o.status = d['status']
        if 'subject' in d:
            o.subject = d['subject']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCardBenefitQueryModel(object):

    def __init__(self):
        self._benefit_id = None
        self._template_id = None

    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardBenefitQueryModel()
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantIDInfo(object):

    def __init__(self):
        self._pid = None
        self._seller_id = None
        self._sub_merchant_id = None

    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.sub_merchant_id:
            if hasattr(self.sub_merchant_id, 'to_alipay_dict'):
                params['sub_merchant_id'] = self.sub_merchant_id.to_alipay_dict()
            else:
                params['sub_merchant_id'] = self.sub_merchant_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantIDInfo()
        if 'pid' in d:
            o.pid = d['pid']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'sub_merchant_id' in d:
            o.sub_merchant_id = d['sub_merchant_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainDefinInsuranceEpolicyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinInsuranceEpolicyQueryResponse, self).__init__()
        self._policy_url = None

    @property
    def policy_url(self):
        return self._policy_url

    @policy_url.setter
    def policy_url(self, value):
        self._policy_url = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinInsuranceEpolicyQueryResponse, self).parse_response_content(response_content)
        if 'policy_url' in response:
            self.policy_url = response['policy_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DishonestyDetailInfo(object):

    def __init__(self):
        self._behavior = None
        self._case_code = None
        self._enforce_court = None
        self._id_number = None
        self._name = None
        self._performance = None
        self._publish_date = None
        self._region = None

    @property
    def behavior(self):
        return self._behavior

    @behavior.setter
    def behavior(self, value):
        self._behavior = value
    @property
    def case_code(self):
        return self._case_code

    @case_code.setter
    def case_code(self, value):
        self._case_code = value
    @property
    def enforce_court(self):
        return self._enforce_court

    @enforce_court.setter
    def enforce_court(self, value):
        self._enforce_court = value
    @property
    def id_number(self):
        return self._id_number

    @id_number.setter
    def id_number(self, value):
        self._id_number = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def performance(self):
        return self._performance

    @performance.setter
    def performance(self, value):
        self._performance = value
    @property
    def publish_date(self):
        return self._publish_date

    @publish_date.setter
    def publish_date(self, value):
        self._publish_date = value
    @property
    def region(self):
        return self._region

    @region.setter
    def region(self, value):
        self._region = value


    def to_alipay_dict(self):
        params = dict()
        if self.behavior:
            if hasattr(self.behavior, 'to_alipay_dict'):
                params['behavior'] = self.behavior.to_alipay_dict()
            else:
                params['behavior'] = self.behavior
        if self.case_code:
            if hasattr(self.case_code, 'to_alipay_dict'):
                params['case_code'] = self.case_code.to_alipay_dict()
            else:
                params['case_code'] = self.case_code
        if self.enforce_court:
            if hasattr(self.enforce_court, 'to_alipay_dict'):
                params['enforce_court'] = self.enforce_court.to_alipay_dict()
            else:
                params['enforce_court'] = self.enforce_court
        if self.id_number:
            if hasattr(self.id_number, 'to_alipay_dict'):
                params['id_number'] = self.id_number.to_alipay_dict()
            else:
                params['id_number'] = self.id_number
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.performance:
            if hasattr(self.performance, 'to_alipay_dict'):
                params['performance'] = self.performance.to_alipay_dict()
            else:
                params['performance'] = self.performance
        if self.publish_date:
            if hasattr(self.publish_date, 'to_alipay_dict'):
                params['publish_date'] = self.publish_date.to_alipay_dict()
            else:
                params['publish_date'] = self.publish_date
        if self.region:
            if hasattr(self.region, 'to_alipay_dict'):
                params['region'] = self.region.to_alipay_dict()
            else:
                params['region'] = self.region
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DishonestyDetailInfo()
        if 'behavior' in d:
            o.behavior = d['behavior']
        if 'case_code' in d:
            o.case_code = d['case_code']
        if 'enforce_court' in d:
            o.enforce_court = d['enforce_court']
        if 'id_number' in d:
            o.id_number = d['id_number']
        if 'name' in d:
            o.name = d['name']
        if 'performance' in d:
            o.performance = d['performance']
        if 'publish_date' in d:
            o.publish_date = d['publish_date']
        if 'region' in d:
            o.region = d['region']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvolvedEntity(object):

    def __init__(self):
        self._code = None
        self._code_type = None
        self._name = None
        self._type = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def code_type(self):
        return self._code_type

    @code_type.setter
    def code_type(self, value):
        self._code_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.code_type:
            if hasattr(self.code_type, 'to_alipay_dict'):
                params['code_type'] = self.code_type.to_alipay_dict()
            else:
                params['code_type'] = self.code_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvolvedEntity()
        if 'code' in d:
            o.code = d['code']
        if 'code_type' in d:
            o.code_type = d['code_type']
        if 'name' in d:
            o.name = d['name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOfflineMarketingVoucherOfflineResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOfflineMarketingVoucherOfflineResponse, self).__init__()
        self._voucher_id = None
        self._voucher_status = None

    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_status(self):
        return self._voucher_status

    @voucher_status.setter
    def voucher_status(self, value):
        self._voucher_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOfflineMarketingVoucherOfflineResponse, self).parse_response_content(response_content)
        if 'voucher_id' in response:
            self.voucher_id = response['voucher_id']
        if 'voucher_status' in response:
            self.voucher_status = response['voucher_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BatchDetailInfo import BatchDetailInfo
from alipay.aop.api.domain.BatchDetailInfo import BatchDetailInfo
from alipay.aop.api.domain.BatchDetailInfo import BatchDetailInfo


class AlipayFundTransAacollectBatchQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransAacollectBatchQueryResponse, self).__init__()
        self._batch_memo = None
        self._batch_no = None
        self._batch_status = None
        self._biz_type = None
        self._create_date = None
        self._creater_user_id = None
        self._detail_list = None
        self._ext_param = None
        self._paid_detail_list = None
        self._pay_amount_single = None
        self._pay_amount_total = None
        self._pay_amount_total_for_receiver = None
        self._real_items_total = None
        self._show_items_total = None
        self._success_amount_total = None
        self._time_out_value = None
        self._unpaid_detail_list = None

    @property
    def batch_memo(self):
        return self._batch_memo

    @batch_memo.setter
    def batch_memo(self, value):
        self._batch_memo = value
    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def batch_status(self):
        return self._batch_status

    @batch_status.setter
    def batch_status(self, value):
        self._batch_status = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def create_date(self):
        return self._create_date

    @create_date.setter
    def create_date(self, value):
        self._create_date = value
    @property
    def creater_user_id(self):
        return self._creater_user_id

    @creater_user_id.setter
    def creater_user_id(self, value):
        self._creater_user_id = value
    @property
    def detail_list(self):
        return self._detail_list

    @detail_list.setter
    def detail_list(self, value):
        if isinstance(value, list):
            self._detail_list = list()
            for i in value:
                if isinstance(i, BatchDetailInfo):
                    self._detail_list.append(i)
                else:
                    self._detail_list.append(BatchDetailInfo.from_alipay_dict(i))
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def paid_detail_list(self):
        return self._paid_detail_list

    @paid_detail_list.setter
    def paid_detail_list(self, value):
        if isinstance(value, list):
            self._paid_detail_list = list()
            for i in value:
                if isinstance(i, BatchDetailInfo):
                    self._paid_detail_list.append(i)
                else:
                    self._paid_detail_list.append(BatchDetailInfo.from_alipay_dict(i))
    @property
    def pay_amount_single(self):
        return self._pay_amount_single

    @pay_amount_single.setter
    def pay_amount_single(self, value):
        self._pay_amount_single = value
    @property
    def pay_amount_total(self):
        return self._pay_amount_total

    @pay_amount_total.setter
    def pay_amount_total(self, value):
        self._pay_amount_total = value
    @property
    def pay_amount_total_for_receiver(self):
        return self._pay_amount_total_for_receiver

    @pay_amount_total_for_receiver.setter
    def pay_amount_total_for_receiver(self, value):
        self._pay_amount_total_for_receiver = value
    @property
    def real_items_total(self):
        return self._real_items_total

    @real_items_total.setter
    def real_items_total(self, value):
        self._real_items_total = value
    @property
    def show_items_total(self):
        return self._show_items_total

    @show_items_total.setter
    def show_items_total(self, value):
        self._show_items_total = value
    @property
    def success_amount_total(self):
        return self._success_amount_total

    @success_amount_total.setter
    def success_amount_total(self, value):
        self._success_amount_total = value
    @property
    def time_out_value(self):
        return self._time_out_value

    @time_out_value.setter
    def time_out_value(self, value):
        self._time_out_value = value
    @property
    def unpaid_detail_list(self):
        return self._unpaid_detail_list

    @unpaid_detail_list.setter
    def unpaid_detail_list(self, value):
        if isinstance(value, list):
            self._unpaid_detail_list = list()
            for i in value:
                if isinstance(i, BatchDetailInfo):
                    self._unpaid_detail_list.append(i)
                else:
                    self._unpaid_detail_list.append(BatchDetailInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransAacollectBatchQueryResponse, self).parse_response_content(response_content)
        if 'batch_memo' in response:
            self.batch_memo = response['batch_memo']
        if 'batch_no' in response:
            self.batch_no = response['batch_no']
        if 'batch_status' in response:
            self.batch_status = response['batch_status']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'create_date' in response:
            self.create_date = response['create_date']
        if 'creater_user_id' in response:
            self.creater_user_id = response['creater_user_id']
        if 'detail_list' in response:
            self.detail_list = response['detail_list']
        if 'ext_param' in response:
            self.ext_param = response['ext_param']
        if 'paid_detail_list' in response:
            self.paid_detail_list = response['paid_detail_list']
        if 'pay_amount_single' in response:
            self.pay_amount_single = response['pay_amount_single']
        if 'pay_amount_total' in response:
            self.pay_amount_total = response['pay_amount_total']
        if 'pay_amount_total_for_receiver' in response:
            self.pay_amount_total_for_receiver = response['pay_amount_total_for_receiver']
        if 'real_items_total' in response:
            self.real_items_total = response['real_items_total']
        if 'show_items_total' in response:
            self.show_items_total = response['show_items_total']
        if 'success_amount_total' in response:
            self.success_amount_total = response['success_amount_total']
        if 'time_out_value' in response:
            self.time_out_value = response['time_out_value']
        if 'unpaid_detail_list' in response:
            self.unpaid_detail_list = response['unpaid_detail_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicShortlinkCreateModel(object):

    def __init__(self):
        self._remark = None
        self._scene_id = None

    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def scene_id(self):
        return self._scene_id

    @scene_id.setter
    def scene_id(self, value):
        self._scene_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.scene_id:
            if hasattr(self.scene_id, 'to_alipay_dict'):
                params['scene_id'] = self.scene_id.to_alipay_dict()
            else:
                params['scene_id'] = self.scene_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicShortlinkCreateModel()
        if 'remark' in d:
            o.remark = d['remark']
        if 'scene_id' in d:
            o.scene_id = d['scene_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OperatorQuery import OperatorQuery


class AlipayOpenAuthOperatorInfoQueryModel(object):

    def __init__(self):
        self._operator_query = None
        self._tenant_id = None

    @property
    def operator_query(self):
        return self._operator_query

    @operator_query.setter
    def operator_query(self, value):
        if isinstance(value, OperatorQuery):
            self._operator_query = value
        else:
            self._operator_query = OperatorQuery.from_alipay_dict(value)
    @property
    def tenant_id(self):
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, value):
        self._tenant_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.operator_query:
            if hasattr(self.operator_query, 'to_alipay_dict'):
                params['operator_query'] = self.operator_query.to_alipay_dict()
            else:
                params['operator_query'] = self.operator_query
        if self.tenant_id:
            if hasattr(self.tenant_id, 'to_alipay_dict'):
                params['tenant_id'] = self.tenant_id.to_alipay_dict()
            else:
                params['tenant_id'] = self.tenant_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAuthOperatorInfoQueryModel()
        if 'operator_query' in d:
            o.operator_query = d['operator_query']
        if 'tenant_id' in d:
            o.tenant_id = d['tenant_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAccountBindingSyncModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._create_time = None
        self._data_version = None
        self._havana_user_id = None
        self._modify_time = None
        self._realm = None
        self._status = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def data_version(self):
        return self._data_version

    @data_version.setter
    def data_version(self, value):
        self._data_version = value
    @property
    def havana_user_id(self):
        return self._havana_user_id

    @havana_user_id.setter
    def havana_user_id(self, value):
        self._havana_user_id = value
    @property
    def modify_time(self):
        return self._modify_time

    @modify_time.setter
    def modify_time(self, value):
        self._modify_time = value
    @property
    def realm(self):
        return self._realm

    @realm.setter
    def realm(self, value):
        self._realm = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.data_version:
            if hasattr(self.data_version, 'to_alipay_dict'):
                params['data_version'] = self.data_version.to_alipay_dict()
            else:
                params['data_version'] = self.data_version
        if self.havana_user_id:
            if hasattr(self.havana_user_id, 'to_alipay_dict'):
                params['havana_user_id'] = self.havana_user_id.to_alipay_dict()
            else:
                params['havana_user_id'] = self.havana_user_id
        if self.modify_time:
            if hasattr(self.modify_time, 'to_alipay_dict'):
                params['modify_time'] = self.modify_time.to_alipay_dict()
            else:
                params['modify_time'] = self.modify_time
        if self.realm:
            if hasattr(self.realm, 'to_alipay_dict'):
                params['realm'] = self.realm.to_alipay_dict()
            else:
                params['realm'] = self.realm
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAccountBindingSyncModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'data_version' in d:
            o.data_version = d['data_version']
        if 'havana_user_id' in d:
            o.havana_user_id = d['havana_user_id']
        if 'modify_time' in d:
            o.modify_time = d['modify_time']
        if 'realm' in d:
            o.realm = d['realm']
        if 'status' in d:
            o.status = d['status']
        return o


